@@ -325,12 +325,18 @@ def _verify_app_source_dir(src_dir, enforce=True):
     files_with_problems = []
     for dirpath, dirnames, filenames in os.walk(os.path.abspath(os.path.join(src_dir, "resources"))):
         for filename in filenames:
-            try:
-                _check_file_syntax(os.path.join(dirpath, filename), enforce=True)
-            except subprocess.CalledProcessError:
-                # Suppresses errors from _check_file_syntax so we only
-                # print a nice error message
-                files_with_problems.append(os.path.join(dirpath, filename))
+            # On Mac OS, the resource fork for "FILE.EXT" gets tarred up
+            # as a file named "._FILE.EXT". To a naive check this
+            # appears to be a file of the same extension. Therefore, we
+            # exclude these from syntax checking since they are likely
+            # to not parse as whatever language they appear to be.
+            if not filename.startswith("._"):
+                try:
+                    _check_file_syntax(os.path.join(dirpath, filename), enforce=True)
+                except subprocess.CalledProcessError:
+                    # Suppresses errors from _check_file_syntax so we
+                    # only print a nice error message
+                    files_with_problems.append(os.path.join(dirpath, filename))
 
     if files_with_problems:
         # Make a message of the form:
@@ -444,7 +450,7 @@ def _build_app_remote(mode, src_dir, publish=False, destination_override=None,
         # is huge (e.g. the target directory already has a whole bunch
         # of binaries in it) and interrupt before uploading begins.
         app_tarball_file = os.path.join(temp_dir, "app_tarball.tar.gz")
-        tar_subprocess = subprocess.Popen(["tar", "-czf", "-", ".", "--exclude", "./.git"], cwd=src_dir, stdout=subprocess.PIPE)
+        tar_subprocess = subprocess.Popen(["tar", "-czf", "-", "--exclude", "./.git", "."], cwd=src_dir, stdout=subprocess.PIPE)
         with open(app_tarball_file, 'w') as tar_output_file:
             total_num_bytes = 0
             last_console_update = 0
